version 12.1

use dataset2.dta, clear

* FIGURE 4 Effects of Selected Fiscal Scheme Attributes on Probability of Being Selected by Trustworthiness

******************  FIGURE 4: ECONOMIC POLICY CONJOINT PANELS
******** Fiscal union conjoint

****** Creating Trust in the European Union variable
* Q013_03_W3_2015 * Quanta fiducia ha nei confronti delle seguenti istituzioni?: L'Unione Europea
* 1 low trust, 4 high trust, 5 do not know
* do not know
drop if Q013_03_W3_2015==5
rename Q013_03_W3_2015 trust

* Dependent variable FU1: choice of fiscal union
reg FU1 i.taxrate i.taxtype i.spend i.spendtype i.spendinst i.contrinst ///
i.taxrate##c.trust i.taxtype##c.trust i.spend##c.trust i.spendtype##c.trust i.spendinst##c.trust i.contrinst##c.trust, cl(ID)
estimates save m1.ster, replace

* Taxrate at 10ɍ
estimates use m1.ster
est des
preserve
drawnorm MG_b1-MG_b43, n(10000) means(e(b)) cov(e(V)) clear seed(1)
postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace
noisily display "start"
local a=1 
while `a' <= 4 {
{
generate x_betahat0 = MG_b1 
generate x_betahat1 = MG_b4 + MG_b23*(`a')
gen prob0=normal(x_betahat0)
gen prob1=normal(x_betahat1)
gen diff=prob1-prob0
egen probhat0=mean(prob0)
egen probhat1=mean(prob1)
egen diffhat=mean(diff)
tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi   
_pctile prob0, p(2.5,97.5) 
scalar `lo0' = r(r1)
scalar `hi0' = r(r2)  
_pctile prob1, p(2.5,97.5)
scalar `lo1'= r(r1)
scalar `hi1'= r(r2)  
_pctile diff, p(2.5,97.5)
scalar `diff_lo'= r(r1)
scalar `diff_hi'= r(r2)  
scalar `prob_hat0'=probhat0
scalar `prob_hat1'=probhat1
scalar `diff_hat'=diffhat
post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
}
drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat 
local a=`a'+ 0.05
display "." _c 
} 
display ""
postclose mypost
use sim.dta, clear
gen MV = _n
eclplot diff_hat diff_hi diff_lo MV, estopts(msize(small)) rplottype(rspike) ciopts(msize(small)) graphregion(fcolor(white)) ysca(noline) xsca(noline) ytitle(" ", size(2.5)) xtitle("Trustworthiness: EU", size(2.5)) ///
xlabel(1 "low" 31 "middle" 61 "high", labsize(2.5)) ylabel(-.08 "-0.08" -.06 "-0.06" -.04 "-0.04" -.02 "-0.02" 0 "0", labsize(2.5)) title("Tax rate 10‰", size(2.5)) ///
yline(0, lcolor(black) lwidth(medthin)) saving(Tax4_trustEUfig4, replace)

* National Government
restore, not
estimates use m1.ster
est des
preserve
drawnorm MG_b1-MG_b43, n(10000) means(e(b)) cov(e(V)) clear seed(1)
postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace
noisily display "start"
local a=1 
while `a' <= 4 {
{
generate x_betahat0 = MG_b14 
generate x_betahat1 = MG_b15 + MG_b38*(`a')
gen prob0=normal(x_betahat0)
gen prob1=normal(x_betahat1)
gen diff=prob1-prob0
egen probhat0=mean(prob0)
egen probhat1=mean(prob1)
egen diffhat=mean(diff)
tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi   
_pctile prob0, p(2.5,97.5) 
scalar `lo0' = r(r1)
scalar `hi0' = r(r2)  
_pctile prob1, p(2.5,97.5)
scalar `lo1'= r(r1)
scalar `hi1'= r(r2)  
_pctile diff, p(2.5,97.5)
scalar `diff_lo'= r(r1)
scalar `diff_hi'= r(r2)  
scalar `prob_hat0'=probhat0
scalar `prob_hat1'=probhat1
scalar `diff_hat'=diffhat
post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
}
drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat 
local a=`a'+ 0.1
display "." _c 
} 
display ""
postclose mypost
use sim.dta, clear
gen MV = _n
eclplot diff_hat diff_hi diff_lo MV, estopts(msize(small)) rplottype(rspike) ciopts(msize(small)) graphregion(fcolor(white)) ysca(noline) xsca(noline) ytitle(" ", size(2.5)) xtitle("Trustworthiness: EU", size(2.5)) ///
xlabel(1 "low" 15 "middle" 31 "high", labsize(2.5)) ylabel(-0.04 "-0.04" -0.02 "-0.02" 0 "0" 0.02 "0.02" , labsize(2.5)) title("Spending institution: National government", size(2.5)) ///
yline(0, lcolor(black) lwidth(medthin)) saving(Spendinst2_trustEUfig4, replace)

clear all
restore, not

use dataset2.dta, clear

****** Creating Trust in the Greek Government variable
* Q107_02_W3_2015 Quanta fiducia ha nei confronti delle seguenti istituzioni?Esprima il Suo giudizio su una scala che va da 'nessuna fiducia' a 'molta fiducia'.: Il governo greco
* 1 low trust, 4 high trust, 5 do not know
* do not know
drop if Q107_02_W3_2015==5
rename Q107_02_W3_2015 trust

* Dependent variable FU1: choice of fiscal union
reg FU1 i.taxrate i.taxtype i.spend i.spendtype i.spendinst i.contrinst ///
i.taxrate##c.trust i.taxtype##c.trust i.spend##c.trust i.spendtype##c.trust i.spendinst##c.trust i.contrinst##c.trust, cl(ID)
estimates save m1.ster, replace

**********   TAXRATE
* Taxrate at 3ɍ
estimates use m1.ster
est des
preserve
drawnorm MG_b1-MG_b43, n(10000) means(e(b)) cov(e(V)) clear seed(1)
postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace
noisily display "start"
local a=1 
while `a' <= 4 {
{
generate x_betahat0 = MG_b1 
generate x_betahat1 = MG_b2 + MG_b21*(`a')
gen prob0=normal(x_betahat0)
gen prob1=normal(x_betahat1)
gen diff=prob1-prob0
egen probhat0=mean(prob0)
egen probhat1=mean(prob1)
egen diffhat=mean(diff)
tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi   
_pctile prob0, p(2.5,97.5) 
scalar `lo0' = r(r1)
scalar `hi0' = r(r2)  
_pctile prob1, p(2.5,97.5)
scalar `lo1'= r(r1)
scalar `hi1'= r(r2)  
_pctile diff, p(2.5,97.5)
scalar `diff_lo'= r(r1)
scalar `diff_hi'= r(r2)  
scalar `prob_hat0'=probhat0
scalar `prob_hat1'=probhat1
scalar `diff_hat'=diffhat
post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
}
drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat 
local a=`a'+ 0.05
display "." _c 
} 
display ""
postclose mypost
use sim.dta, clear
gen MV = _n
eclplot diff_hat diff_hi diff_lo MV, estopts(msize(small)) rplottype(rspike) ciopts(msize(small)) graphregion(fcolor(white)) ysca(noline) xsca(noline) ytitle(" ", size(2.5)) xtitle("Trustworthiness: Greek Government", size(2.5)) ///
xlabel(1 "low" 31 "middle" 61 "high", labsize(2.5)) ylabel(-.04 "-0.04" -.02 "-0.02" 0 "0" .02 "0.02" .04 "0.04", labsize(2.5)) title("Tax rate 3‰", size(2.5)) ///
yline(0, lcolor(black) lwidth(medthin)) saving(Tax2_trustGovGrefig4, replace)

* Taxrate at 5ɍ
restore, not
estimates use m1.ster
est des
preserve
drawnorm MG_b1-MG_b43, n(10000) means(e(b)) cov(e(V)) clear seed(1)
postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace
noisily display "start"
local a=1 
while `a' <= 4 {
{
generate x_betahat0 = MG_b1 
generate x_betahat1 = MG_b3 + MG_b22*(`a')
gen prob0=normal(x_betahat0)
gen prob1=normal(x_betahat1)
gen diff=prob1-prob0
egen probhat0=mean(prob0)
egen probhat1=mean(prob1)
egen diffhat=mean(diff)
tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi   
_pctile prob0, p(2.5,97.5) 
scalar `lo0' = r(r1)
scalar `hi0' = r(r2)  
_pctile prob1, p(2.5,97.5)
scalar `lo1'= r(r1)
scalar `hi1'= r(r2)  
_pctile diff, p(2.5,97.5)
scalar `diff_lo'= r(r1)
scalar `diff_hi'= r(r2)  
scalar `prob_hat0'=probhat0
scalar `prob_hat1'=probhat1
scalar `diff_hat'=diffhat
post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
}
drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat 
local a=`a'+ 0.05
display "." _c 
} 
display ""
postclose mypost
use sim.dta, clear
gen MV = _n
eclplot diff_hat diff_hi diff_lo MV, estopts(msize(small)) rplottype(rspike) ciopts(msize(small)) graphregion(fcolor(white)) ysca(noline) xsca(noline) ytitle(" ", size(2.5)) xtitle("Trustworthiness: Greek Government", size(2.5)) ///
xlabel(1 "low" 31 "middle" 61 "high", labsize(2.5)) ylabel(-.06 "-0.06" -.04 "-0.04" -.02 "-0.02" 0 "0" .02 "0.02" .04 "0.04", labsize(2.5)) title("Tax rate 5‰", size(2.5)) ///
yline(0, lcolor(black) lwidth(medthin)) saving(Tax3_trustGovGrefig4, replace)

* Taxrate at 10ɍ
restore, not
estimates use m1.ster
est des
preserve
drawnorm MG_b1-MG_b43, n(10000) means(e(b)) cov(e(V)) clear seed(1)
postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace
noisily display "start"
local a=1 
while `a' <= 4 {
{
generate x_betahat0 = MG_b1 
generate x_betahat1 = MG_b4 + MG_b23*(`a')
gen prob0=normal(x_betahat0)
gen prob1=normal(x_betahat1)
gen diff=prob1-prob0
egen probhat0=mean(prob0)
egen probhat1=mean(prob1)
egen diffhat=mean(diff)
tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi   
_pctile prob0, p(2.5,97.5) 
scalar `lo0' = r(r1)
scalar `hi0' = r(r2)  
_pctile prob1, p(2.5,97.5)
scalar `lo1'= r(r1)
scalar `hi1'= r(r2)  
_pctile diff, p(2.5,97.5)
scalar `diff_lo'= r(r1)
scalar `diff_hi'= r(r2)  
scalar `prob_hat0'=probhat0
scalar `prob_hat1'=probhat1
scalar `diff_hat'=diffhat
post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
}
drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat 
local a=`a'+ 0.05
display "." _c 
} 
display ""
postclose mypost
use sim.dta, clear
gen MV = _n
eclplot diff_hat diff_hi diff_lo MV, estopts(msize(small)) rplottype(rspike) ciopts(msize(small)) graphregion(fcolor(white)) ysca(noline) xsca(noline) ytitle(" ", size(2.5)) xtitle("Trustworthiness: Greek Government", size(2.5)) ///
xlabel(1 "low" 31 "middle" 61 "high", labsize(2.5)) ylabel(-.08 "-0.08" -.06 "-0.06" -.04 "-0.04" -.02 "-0.02" 0 "0", labsize(2.5)) title("Tax rate 10‰", size(2.5)) ///
yline(0, lcolor(black) lwidth(medthin)) saving(Tax4_trustGovGrefig4, replace)

*****  Combine graphs

graph combine Tax4_trustEUfig4.gph Spendinst2_trustEUfig4.gph Tax2_trustGovGrefig4.gph Tax4_trustGovGrefig4.gph, col(2) graphregion(fcolor(white)) imargin(0 0 0 0) saving(figure_4, replace) 



