version 14

use dataset1.dta, clear

******** FIGURE S2 Histograms of Selected Predictors

* Model 1a from Table 1/S3
reg FU   ib3.employed c.faminc i.region c.lr i.EUbad c.identity ///
         c.trust_EU c.trust_It c.trust_Gr c.trust_Ge c.trust_GrP c.trust_GeP c.trust_p i.female c.edu c.age , vce(robust)

* Employment status
hist employed if e(sample)==1, discrete fcolor(gs15) lcolor(black) graphregion(fcolor(white)) ///
xsca(noline r(0.5/4)) xlabel(1 "inactive" 2 "unemployed" 3 "low income" 4 "high income", labsize(2)) title("Employment status", size(2)) ///
xtitle("", size(2)) ysca(noline) ylabel(,labsize(2)) ytitle("Density", size(2)) saving(hist_employed, replace)

* Left-right Partisanship
hist lr if e(sample)==1, discrete fcolor(gs15) lcolor(black) graphregion(fcolor(white)) ///
xsca(noline r(0.5/10)) xlabel(1 "left" 5.5 "centre" 11 "right", labsize(2)) title("Left-right partisanship ", size(2)) ///
xtitle("", size(2)) ysca(noline) ylabel(,labsize(2)) ytitle("Density", size(2)) saving(hist_lr, replace)

*   EU is bad
hist EUbad if e(sample)==1, discrete fcolor(gs15) lcolor(black) graphregion(fcolor(white)) ///
xsca(noline r(0.5/3)) xlabel(1 "bad" 2 "neither" 3 "good", labsize(2)) title("Assessment of EU membership", size(2)) ///
xtitle("", size(2)) ysca(noline) ylabel(,labsize(2)) ytitle("Density", size(2)) saving(hist_EUbad, replace)

*  Feeling European
hist identity if e(sample)==1, discrete fcolor(gs15) lcolor(black) graphregion(fcolor(white)) ///
xsca(noline r(0.5/4)) xlabel(1 "very low" 2 "low" 3 "high" 4 "very high", labsize(2)) title("Feeling European", size(2)) ///
xtitle("", size(2)) ysca(noline) ylabel(,labsize(2)) ytitle("Density", size(2)) saving(hist_identity, replace)

*    Interpersonal trust
hist trust_p if e(sample)==1, discrete fcolor(gs15) lcolor(black) graphregion(fcolor(white)) ///
xsca(noline r(0.5/7)) xlabel(1 "low" 3.5 "middle" 7 "high", labsize(2)) title("Interpersonal trust", size(2)) ///
xtitle("", size(2)) ysca(noline) ylabel(,labsize(2)) ytitle("Density", size(2)) saving(hist_trustp, replace)

* Trust EU
hist trust_EU if e(sample)==1, discrete fcolor(gs15) lcolor(black) graphregion(fcolor(white)) ///
xsca(noline r(0.5/4)) xlabel(1 "none" 2 "low" 3 "some" 4 "high", labsize(2)) title("Trust in EU", size(2)) ///
xtitle("", size(2)) ysca(noline) ylabel(,labsize(2)) ytitle("Density", size(2)) saving(hist_trustEU, replace)

* Trust Greek Gov
hist trust_Gr if e(sample)==1, discrete fcolor(gs15) lcolor(black) graphregion(fcolor(white)) ///
xsca(noline r(0.5/4)) xlabel(1 "none" 2 "low" 3 "some" 4 "high", labsize(2)) title("Trust in Greek Government", size(2)) ///
xtitle("", size(2)) ysca(noline) ylabel(,labsize(2)) ytitle("Density", size(2)) saving(hist_trustGr, replace)

* Model 1b
reg FU   ib3.employed c.faminc i.region c.lr i.EUbad c.itaeuro ///
         c.trust_EU c.trust_It c.trust_Gr c.trust_Ge c.trust_GrP c.trust_GeP c.trust_p i.female c.edu c.age , vce(robust)

*  Italian vs. European identity
hist itaeuro  if e(sample)==1, discrete fcolor(gs15) lcolor(black) graphregion(fcolor(white)) ///
xsca(noline r(0.5/5)) xlabel(1 "Italian only" 2 "more Italian" 3 "both" 4 "more European" 5 "European only", labsize(2)) title("Italian vs. European identity", size(2)) ///
xtitle("", size(2)) ysca(noline) ylabel(,labsize(2)) ytitle("Density", size(2)) saving(hist_itaeuro, replace)

**********  Combine graphs

graph combine hist_employed.gph hist_lr.gph hist_EUbad.gph hist_identity.gph hist_itaeuro.gph ///
hist_trustp.gph hist_trustEU.gph hist_trustGr.gph, col(2) graphregion(fcolor(white)) imargin(0 0 0 0) saving(figure_s2, replace) 










